instrumenttools.SopranoVoice
============================

.. abjad-lineage:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice

.. autoclass:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.SopranoVoice.SopranoVoice.SopranoVoice.__repr__
   :noindex:
